@@ -40,14 +40,15 @@ use Moose;
 
 use Text::UnicodeBox::Control qw(:all);
 use Text::UnicodeBox::Text qw(:all);
-use Text::UnicodeBox::Utility qw(fetch_box_character);
+use Text::UnicodeBox::Utility qw(normalize_box_character_parameters);
 use Scalar::Util qw(blessed);
 
 has 'buffer_ref' => ( is => 'rw', default => sub { my $buffer = '';  return \$buffer } );
 has 'last_line'  => ( is => 'rw' );
 has 'whitespace_character' => ( is => 'ro', default => ' ' );
+has 'fetch_box_character' => ( is => 'rw' );
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 =head1 METHODS
 
@@ -61,6 +62,12 @@ Create a new instance.  Provide arguments as a list.  Valid arguments are:
 
 When the box renderer needs to pad the output of the interstitial lines of output, this character will be used.  Defaults to a simple space.
 
+=item fetch_box_character
+
+Provide a subroutine which will be used instead of the L<Text::UnicodeBox::Utility/fetch_box_character>.  This allows the user granular control over what symbols will be used for box drawing.  The subroutine will be called with a hash with any or all of the following keys: 'left', 'right', up', 'down', 'vertical' or 'horizontal'.  The value of each will be either '1' (default style), 'light', 'heavy', 'single' or 'double'.
+
+Return a single width character or return undefined and a '?' will be used for rendering.
+
 =back
 
 =head2 buffer
@@ -109,7 +116,7 @@ sub add_line {
 		my %context;
 		foreach my $part (@parts) {
 			$current_line{parts_at_position}{$position} = $part;
-			$line .= $part->to_string(\%context);
+			$line .= $part->to_string(\%context, $self);
 			$position += $part->can('length') ? $part->length : 1;
 		}
 		$line .= "\n";
@@ -226,12 +233,16 @@ sub _generate_box_border_line {
 			delete $symbol{horizontal} unless defined $symbol{horizontal};
 		}
 
+		# Find the character and add it to the line
+		my $char;
 		if (! keys %symbol) {
-			$line .= $self->whitespace_character();
+			$char = $self->whitespace_character();
 		}
 		else {
-			$line .= fetch_box_character(%symbol) || '?';
+			$char = $self->_fetch_box_character(%symbol);
 		}
+		$char = '?' unless defined $char;
+		$line .= $char;
 	}
 
 	$line .= "\n";
@@ -239,6 +250,25 @@ sub _generate_box_border_line {
 	return $line;
 }
 
+sub _fetch_box_character {
+	my ($self, %symbol) = @_;
+	my $cache_key = join ';', map { "$_=$symbol{$_}" } sort keys %symbol;
+	if (exists $self->{_fetch_box_character_cache}{$cache_key}) {
+		return $self->{_fetch_box_character_cache}{$cache_key};
+	}
+	my $char;
+	if ($self->fetch_box_character) {
+		$char = $self->fetch_box_character->(
+			normalize_box_character_parameters(%symbol)
+		);
+	}
+	else {
+		$char = Text::UnicodeBox::Utility::fetch_box_character(%symbol);
+	}
+	$self->{_fetch_box_character_cache}{$cache_key} = $char;
+	return $char;
+}
+
 =head1 DEVELOPMENT
 
 This module is being developed via a git repository publicly avaiable at http://github.com/ewaters/Text-UnicodeBox.  I encourage anyone who is interested to fork my code and contribute bug fixes or new features, or just have fun and be creative.
